package com.cpxt.biz.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cpxt.biz.domain.BizCustomerShop;

/**
 * 门店Service接口
 * 
 * @author YIN
 * @date 2024-12-16
 */
public interface IBizCustomerShopService 
{
    /**
     * 查询门店
     * 
     * @param id 门店主键
     * @return 门店
     */
    public BizCustomerShop selectBizCustomerShopById(Long id);

    /**
     * 查询门店列表
     * 
     * @param bizCustomerShop 门店
     * @return 门店集合
     */
    public List<BizCustomerShop> selectBizCustomerShopList(BizCustomerShop bizCustomerShop);

    /**
     * 新增门店
     * 
     * @param bizCustomerShop 门店
     * @return 结果
     */
    public int insertBizCustomerShop(BizCustomerShop bizCustomerShop);

    /**
     * 修改门店
     * 
     * @param bizCustomerShop 门店
     * @return 结果
     */
    public int updateBizCustomerShop(BizCustomerShop bizCustomerShop);

    /**
     * 批量删除门店
     * 
     * @param ids 需要删除的门店主键集合
     * @return 结果
     */
    public int deleteBizCustomerShopByIds(Long[] ids);

    /**
     * 删除门店信息
     * 
     * @param id 门店主键
     * @return 结果
     */
    public int deleteBizCustomerShopById(Long id);

    Page<BizCustomerShop> selectBizCustomerShopPage(BizCustomerShop bizCustomerShop, int pageNum, int pageSize);
}
